@@ -1,4 +1,3 @@
-import re
 import json
 from subprocess import Popen, PIPE
 from pyduinocli.errors.arduinoerror import ArduinoError
@@ -9,8 +8,6 @@ class CommandBase:
     __ERROR_MESSAGE = "Message"
     __ERROR_CAUSE = "Cause"
 
-    __REGEX_JSON = r'(\{|\[)'
-
     def __init__(self, base_args):
         self._base_args = list(base_args)
 
@@ -27,23 +24,19 @@ class CommandBase:
 
     @staticmethod
     def __parse_output(data):
-        pattern = re.compile(CommandBase.__REGEX_JSON)
-        for match in pattern.finditer(data):
-            candidate = data[match.start():]
-            try:
-                return json.loads(candidate)
-            except ValueError:
-                continue
-        return data
+        try:
+            return json.loads(data)
+        except ValueError:
+            return data
 
     def _exec(self, args):
         command = list(self._base_args)
         command.extend(args)
         try:
-            p = Popen(command, stdout=PIPE, stderr=PIPE, universal_newlines=True)
+            p = Popen(command, stdout=PIPE, stderr=PIPE)
             stdout, stderr = p.communicate()
-            stdout = stdout.strip()
-            stderr = stderr.strip()
+            stdout = stdout.decode("utf-8").strip()
+            stderr = stderr.decode("utf-8").strip()
             decoded_out = self.__parse_output(stdout)
             if p.returncode != 0:
                 if type(decoded_out) is dict:
